@@ -5,21 +5,13 @@ from ak_selenium import Chrome
 def chrome_instance():
     chrome = Chrome(headless=True)
     yield chrome
-    del chrome
-
-def test_init_chrome(chrome_instance):
-    assert chrome_instance.init_chrome()
+    chrome.driver.quit()
 
 def test_implicitly_wait_time(chrome_instance):
     assert chrome_instance.IMPLICITLY_WAIT_TIME == 3
 
 def test_max_wait_time(chrome_instance):
-    assert chrome_instance.MAX_WAIT_TIME == 5
-
-def test_chrome_user_agent(chrome_instance):
-    assert chrome_instance.USERAGENT == 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) \
-                AppleWebKit/537.36 (KHTML, like Gecko) \
-                Chrome/83.0.4103.53 Safari/537.36'
+    assert chrome_instance.MAX_WAIT_TIME == 10
 
 def test_half_screen(chrome_instance):
     assert chrome_instance.half_screen is True
@@ -31,6 +23,6 @@ def test_str_method(chrome_instance):
         Implicit Wait Time: {chrome_instance.IMPLICITLY_WAIT_TIME:.2f}s
         Max Wait Time: {chrome_instance.MAX_WAIT_TIME:.2f}s
         Headless: {chrome_instance.headless}
-        Chrome Userdata Path: {chrome_instance.Chrome_userdata_path}
+        Chrome Userdata Path: {chrome_instance.chrome_userdata_path}
         Half Screen View: {chrome_instance.half_screen}
-        """
\ No newline at end of file
+        """
